@@ -17,12 +17,16 @@
 
 package datasource
 
+import (
+	"github.com/little-cui/etcdadpt"
+)
+
 //Options contains configuration for plugins
 type Options struct {
-	Kind           Kind
-	SslEnabled     bool
-	SchemaEditable bool
+	etcdadpt.Config
+
+	EnableCache bool
 	// InstanceTTL: the default ttl of instance lease
-	InstanceTTL int64
-	// TODO: pay attention to more net config like TLSConfig when coding
+	InstanceTTL        int64
+	InstanceProperties map[string]string
 }
