@@ -24,18 +24,21 @@ import (
 	"testing"
 	"time"
 
+	quotasvc "github.com/apache/servicecomb-service-center/server/service/quota"
+	"github.com/go-chassis/cari/pkg/errsvc"
+
 	"github.com/apache/servicecomb-service-center/datasource"
 	"github.com/apache/servicecomb-service-center/pkg/log"
 	"github.com/apache/servicecomb-service-center/pkg/util"
-	"github.com/apache/servicecomb-service-center/server/plugin/quota"
-	"github.com/apache/servicecomb-service-center/server/service"
 	pb "github.com/go-chassis/cari/discovery"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestService_Register(t *testing.T) {
+	ctx := getContext()
+
 	t.Run("Register service after init & install, should pass", func(t *testing.T) {
-		size := quota.DefaultSchemaQuota + 1
+		size := int(quotasvc.SchemaQuota()) + 1
 		paths := make([]*pb.ServicePath, 0, size)
 		properties := make(map[string]string, size)
 		for i := 0; i < size; i++ {
@@ -54,7 +57,7 @@ func TestService_Register(t *testing.T) {
 				Schemas:     []string{"service-ms-schema"},
 				Paths:       paths,
 				Properties:  properties,
-				Framework: &pb.FrameWorkProperty{
+				Framework: &pb.FrameWork{
 					Name:    "service-ms-frameworkName",
 					Version: "service-ms-frameworkVersion",
 				},
@@ -63,16 +66,14 @@ func TestService_Register(t *testing.T) {
 			},
 		}
 		request.Service.ModTimestamp = request.Service.Timestamp
-		resp, err := datasource.Instance().RegisterService(getContext(), request)
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, request)
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: resp.ServiceId, Force: true})
 	})
 
 	t.Run("register service with same key", func(t *testing.T) {
-		// serviceName: some-relay-ms-service-name
-		// alias: sr-ms-service-name
-		resp, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceName: "some-relay-ms-service-name",
 				Alias:       "sr-ms-service-name",
@@ -87,12 +88,11 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: resp.ServiceId, Force: true})
+
 		sameId := resp.ServiceId
 
-		// serviceName: some-relay-ms-service-name
-		// alias: sr1-ms-service-name
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceName: "some-relay-ms-service-name",
 				Alias:       "sr1-ms-service-name",
@@ -107,11 +107,9 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.Equal(t, sameId, resp.ServiceId)
 
-		// serviceName: some-relay1-ms-service-name
-		// alias: sr-ms-service-name
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceName: "some-relay1-ms-service-name",
 				Alias:       "sr-ms-service-name",
@@ -126,12 +124,9 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.Equal(t, sameId, resp.ServiceId)
 
-		// serviceName: some-relay1-ms-service-name
-		// alias: sr-ms-service-name
-		// add serviceId field: sameId
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceId:   sameId,
 				ServiceName: "some-relay1-ms-service-name",
@@ -147,12 +142,9 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.Equal(t, sameId, resp.ServiceId)
 
-		// serviceName: some-relay-ms-service-name
-		// alias: sr1-ms-service-name
-		// serviceId: sameId
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceId:   sameId,
 				ServiceName: "some-relay-ms-service-name",
@@ -168,15 +160,12 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.Equal(t, sameId, resp.ServiceId)
 
-		// serviceName: some-relay-ms-service-name
-		// alias: sr1-ms-service-name
-		// serviceId: custom-id-ms-service-id -- different
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceId:   "custom-id-ms-service-id",
-				ServiceName: "some-relay-ms-service-name",
+				ServiceName: "some-relay1-ms-service-name",
 				Alias:       "sr1-ms-service-name",
 				AppId:       "default",
 				Version:     "1.0.0",
@@ -189,15 +178,13 @@ func TestService_Register(t *testing.T) {
 		})
 		assert.NotNil(t, resp)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceAlreadyExists, resp.Response.GetCode())
+		assert.NotEqual(t, sameId, resp.ServiceId)
+		defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: "custom-id-ms-service-id", Force: true})
 
-		// serviceName: some-relay1-ms-service-name
-		// alias: sr-ms-service-name
-		// serviceId: custom-id-ms-service-id -- different
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceId:   "custom-id-ms-service-id",
-				ServiceName: "some-relay1-ms-service-name",
+				ServiceName: "some-relay-ms-service-name",
 				Alias:       "sr-ms-service-name",
 				AppId:       "default",
 				Version:     "1.0.0",
@@ -208,55 +195,56 @@ func TestService_Register(t *testing.T) {
 				Status: "UP",
 			},
 		})
-		assert.NotNil(t, resp)
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceAlreadyExists, resp.Response.GetCode())
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceAlreadyExists, testErr.Code)
 	})
 
-	t.Run("same serviceId,different service, can not register again,error is same as the service register twice",
-		func(t *testing.T) {
-			resp, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
-				Service: &pb.MicroService{
-					ServiceId:   "same-serviceId-service-ms",
-					ServiceName: "serviceA-service-ms",
-					AppId:       "default-service-ms",
-					Version:     "1.0.0",
-					Level:       "FRONT",
-					Schemas: []string{
-						"xxxxxxxx",
-					},
-					Status: "UP",
+	t.Run("same serviceId,different service, can not register again, error is same as the service register twice", func(t *testing.T) {
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
+			Service: &pb.MicroService{
+				ServiceId:   "same-serviceId-service-ms",
+				ServiceName: "serviceA-service-ms",
+				AppId:       "default-service-ms",
+				Version:     "1.0.0",
+				Level:       "FRONT",
+				Schemas: []string{
+					"xxxxxxxx",
 				},
-			})
-
-			assert.NotNil(t, resp)
-			assert.NoError(t, err)
-			assert.Equal(t, resp.Response.GetCode(), pb.ResponseSuccess)
-
-			// same serviceId with different service name
-			resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
-				Service: &pb.MicroService{
-					ServiceId:   "same-serviceId-service-ms",
-					ServiceName: "serviceB-service-ms",
-					AppId:       "default-service-ms",
-					Version:     "1.0.0",
-					Level:       "FRONT",
-					Schemas: []string{
-						"xxxxxxxx",
-					},
-					Status: "UP",
-				},
-			})
-			assert.NotNil(t, resp)
-			assert.NoError(t, err)
-			assert.Equal(t, pb.ErrServiceAlreadyExists, resp.Response.GetCode())
+				Status: "UP",
+			},
 		})
+
+		assert.NotNil(t, resp)
+		assert.NoError(t, err)
+		defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: resp.ServiceId, Force: true})
+
+		// same serviceId with different service name
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
+			Service: &pb.MicroService{
+				ServiceId:   "same-serviceId-service-ms",
+				ServiceName: "serviceB-service-ms",
+				AppId:       "default-service-ms",
+				Version:     "1.0.0",
+				Level:       "FRONT",
+				Schemas: []string{
+					"xxxxxxxx",
+				},
+				Status: "UP",
+			},
+		})
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceAlreadyExists, testErr.Code)
+	})
 }
 
 func TestService_Get(t *testing.T) {
+	ctx := getContext()
+
 	// get service test
 	t.Run("query all services, should pass", func(t *testing.T) {
-		resp, err := datasource.Instance().GetServices(getContext(), &pb.GetServicesRequest{})
+		resp, err := datasource.GetMetadataManager().ListService(ctx, &pb.GetServicesRequest{})
 		assert.NoError(t, err)
 		assert.Greater(t, len(resp.Services), 0)
 	})
@@ -273,25 +261,24 @@ func TestService_Get(t *testing.T) {
 			},
 		}
 
-		resp, err := datasource.Instance().RegisterService(getContext(), request)
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, request)
 		assert.NoError(t, err)
-		assert.Equal(t, resp.Response.GetCode(), pb.ResponseSuccess)
+		defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: resp.ServiceId, Force: true})
 
 		// search service by serviceID
-		queryResp, err := datasource.Instance().GetService(getContext(), &pb.GetServiceRequest{
+		_, err = datasource.GetMetadataManager().GetService(ctx, &pb.GetServiceRequest{
 			ServiceId: "ms-service-query-id",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, queryResp.Response.GetCode(), pb.ResponseSuccess)
 	})
 
 	t.Run("query a service by a not existed serviceId, should not pass", func(t *testing.T) {
 		// not exist service
-		resp, err := datasource.Instance().GetService(getContext(), &pb.GetServiceRequest{
+		_, err := datasource.GetMetadataManager().GetService(ctx, &pb.GetServiceRequest{
 			ServiceId: "no-exist-service",
 		})
-		assert.NoError(t, err)
-		assert.Equal(t, resp.Response.GetCode(), pb.ErrServiceNotExists)
+		assert.NotNil(t, err)
+		assert.Equal(t, pb.ErrServiceNotExists, err.(*errsvc.Error).Code)
 	})
 }
 
@@ -300,6 +287,10 @@ func TestService_Exist(t *testing.T) {
 		serviceId1 string
 		serviceId2 string
 	)
+	ctx := getContext()
+	defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: serviceId1, Force: true})
+	defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: serviceId2, Force: true})
+
 	t.Run("create service", func(t *testing.T) {
 		svc := &pb.MicroService{
 			Alias:       "es_service_ms",
@@ -312,7 +303,7 @@ func TestService_Exist(t *testing.T) {
 			},
 			Status: "UP",
 		}
-		resp, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: svc,
 		})
 		assert.NoError(t, err)
@@ -321,7 +312,7 @@ func TestService_Exist(t *testing.T) {
 
 		svc.ServiceId = ""
 		svc.Environment = pb.ENV_PROD
-		resp, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err = datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: svc,
 		})
 		assert.NoError(t, err)
@@ -331,136 +322,104 @@ func TestService_Exist(t *testing.T) {
 
 	t.Run("check exist when service does not exist", func(t *testing.T) {
 		log.Info("check by querying a not exist serviceName")
-		resp, err := datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		_, err := datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			AppId:       "exist_appId",
 			ServiceName: "notExistService_service_ms",
 			Version:     "1.0.0",
 		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceNotExists, resp.Response.GetCode())
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceNotExists, testErr.Code)
 
 		log.Info("check by querying a not exist env")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		_, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			Environment: pb.ENV_TEST,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "exist_service_service_ms",
 			Version:     "1.0.0",
 		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceNotExists, resp.Response.GetCode())
+		testErr = err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceNotExists, testErr.Code)
 
 		log.Info("check by querying a not exist env with alias")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		_, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			Environment: pb.ENV_TEST,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "es_service_ms",
 			Version:     "1.0.0",
 		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceNotExists, resp.Response.GetCode())
+		testErr = err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceNotExists, testErr.Code)
 
 		log.Info("check by querying with a mismatching version")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		_, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "exist_service_service_ms",
 			Version:     "2.0.0",
 		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceNotExists, resp.Response.GetCode())
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
-			AppId:       "exist_appId_service_ms",
-			ServiceName: "exist_service_service_ms",
-			Version:     "0.0.0-1.0.0",
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ErrServiceVersionNotExists, resp.Response.GetCode())
+		testErr = err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceVersionNotExists, testErr.Code)
 	})
 
 	t.Run("check exist when service exists", func(t *testing.T) {
 		log.Info("search with serviceName")
-		resp, err := datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		serviceID, err := datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "exist_service_service_ms",
 			Version:     "1.0.0",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, serviceId1, resp.ServiceId)
+		assert.Equal(t, serviceId1, serviceID)
 
 		log.Info("check with serviceName and env")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		serviceID, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			Environment: pb.ENV_PROD,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "exist_service_service_ms",
 			Version:     "1.0.0",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, serviceId2, resp.ServiceId)
+		assert.Equal(t, serviceId2, serviceID)
 
 		log.Info("check with alias")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		serviceID, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "es_service_ms",
 			Version:     "1.0.0",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, serviceId1, resp.ServiceId)
+		assert.Equal(t, serviceId1, serviceID)
 
 		log.Info("check with alias and env")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
+		serviceID, err = datasource.GetMetadataManager().ExistService(ctx, &pb.GetExistenceRequest{
+			Type:        datasource.ExistTypeMicroservice,
 			Environment: pb.ENV_PROD,
 			AppId:       "exist_appId_service_ms",
 			ServiceName: "es_service_ms",
 			Version:     "1.0.0",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, serviceId2, resp.ServiceId)
-
-		log.Info("check with latest versionRule")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
-			AppId:       "exist_appId_service_ms",
-			ServiceName: "es_service_ms",
-			Version:     "latest",
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, serviceId1, resp.ServiceId)
-
-		log.Info("check with 1.0.0+ versionRule")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
-			AppId:       "exist_appId_service_ms",
-			ServiceName: "es_service_ms",
-			Version:     "1.0.0+",
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, serviceId1, resp.ServiceId)
-
-		log.Info("check with range versionRule")
-		resp, err = datasource.Instance().ExistService(getContext(), &pb.GetExistenceRequest{
-			Type:        service.ExistTypeMicroservice,
-			AppId:       "exist_appId_service_ms",
-			ServiceName: "es_service_ms",
-			Version:     "0.9.1-1.0.1",
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, serviceId1, resp.ServiceId)
+		assert.Equal(t, serviceId2, serviceID)
 	})
 }
 
 func TestService_Update(t *testing.T) {
 	var serviceId string
+	ctx := getContext()
+	defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: serviceId, Force: true})
 
 	t.Run("create service", func(t *testing.T) {
-		resp, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				Alias:       "es_service_ms",
 				ServiceName: "update_prop_service_service_ms",
@@ -472,7 +431,6 @@ func TestService_Update(t *testing.T) {
 		})
 		assert.NoError(t, err)
 		assert.NotNil(t, resp)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 		assert.NotEqual(t, "", resp.ServiceId)
 		serviceId = resp.ServiceId
 	})
@@ -489,21 +447,19 @@ func TestService_Update(t *testing.T) {
 		}
 		request.Properties["test"] = "1"
 		request2.Properties["k"] = "v"
-		resp, err := datasource.Instance().UpdateService(getContext(), request)
+		err := datasource.GetMetadataManager().PutServiceProperties(ctx, request)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		resp, err = datasource.Instance().UpdateService(getContext(), request2)
+		err = datasource.GetMetadataManager().PutServiceProperties(ctx, request2)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		respGetService, err := datasource.Instance().GetService(getContext(), &pb.GetServiceRequest{
+		service, err := datasource.GetMetadataManager().GetService(ctx, &pb.GetServiceRequest{
 			ServiceId: serviceId,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, serviceId, respGetService.Service.ServiceId)
-		assert.Equal(t, "", respGetService.Service.Properties["test"])
-		assert.Equal(t, "v", respGetService.Service.Properties["k"])
+		assert.Equal(t, serviceId, service.ServiceId)
+		assert.Equal(t, "", service.Properties["test"])
+		assert.Equal(t, "v", service.Properties["k"])
 	})
 
 	t.Run("update service that does not exist", func(t *testing.T) {
@@ -512,9 +468,10 @@ func TestService_Update(t *testing.T) {
 			ServiceId:  "not_exist_service_service_ms",
 			Properties: make(map[string]string),
 		}
-		resp, err := datasource.Instance().UpdateService(getContext(), r)
-		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, resp.Response.GetCode())
+		err := datasource.GetMetadataManager().PutServiceProperties(ctx, r)
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceNotExists, testErr.Code)
 	})
 
 	t.Run("update service by removing the properties", func(t *testing.T) {
@@ -523,18 +480,18 @@ func TestService_Update(t *testing.T) {
 			ServiceId:  serviceId,
 			Properties: nil,
 		}
-		resp, err := datasource.Instance().UpdateService(getContext(), r)
+		err := datasource.GetMetadataManager().PutServiceProperties(ctx, r)
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
 		log.Info("remove properties for service with empty serviceId")
 		r = &pb.UpdateServicePropsRequest{
 			ServiceId:  "",
 			Properties: map[string]string{},
 		}
-		resp, err = datasource.Instance().UpdateService(getContext(), r)
-		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, resp.Response.GetCode())
+		err = datasource.GetMetadataManager().PutServiceProperties(ctx, r)
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrServiceNotExists, testErr.Code)
 	})
 }
 
@@ -545,7 +502,7 @@ func TestService_Delete(t *testing.T) {
 	)
 
 	t.Run("create service & instance", func(t *testing.T) {
-		respCreate, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		respCreate, err := datasource.GetMetadataManager().RegisterService(getContext(), &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				ServiceName: "delete_service_with_inst_ms",
 				AppId:       "delete_service_ms",
@@ -555,7 +512,6 @@ func TestService_Delete(t *testing.T) {
 			},
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respCreate.Response.GetCode())
 		serviceContainInstId = respCreate.ServiceId
 
 		log.Info("attach instance")
@@ -567,11 +523,10 @@ func TestService_Delete(t *testing.T) {
 			HostName: "delete-host-ms",
 			Status:   pb.MSI_UP,
 		}
-		respCreateIns, err := datasource.Instance().RegisterInstance(getContext(), &pb.RegisterInstanceRequest{
+		_, err = datasource.GetMetadataManager().RegisterInstance(getContext(), &pb.RegisterInstanceRequest{
 			Instance: instance,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respCreateIns.Response.GetCode())
 
 		log.Info("create service without instance")
 		provider := &pb.MicroService{
@@ -581,97 +536,131 @@ func TestService_Delete(t *testing.T) {
 			Level:       "FRONT",
 			Status:      "UP",
 		}
-		respCreate, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		respCreate, err = datasource.GetMetadataManager().RegisterService(getContext(), &pb.CreateServiceRequest{
 			Service: provider,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respCreate.Response.GetCode())
 		serviceNoInstId = respCreate.ServiceId
+	})
 
-		respCreate, err = datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+	t.Run("delete a service which contains instances with no force flag", func(t *testing.T) {
+		err := datasource.GetMetadataManager().UnregisterService(getContext(), &pb.DeleteServiceRequest{
+			ServiceId: serviceContainInstId,
+			Force:     false,
+		})
+		testErr := err.(*errsvc.Error)
+		assert.Error(t, testErr)
+		assert.Equal(t, pb.ErrDeployedInstance, testErr.Code)
+	})
+
+	t.Run("delete a service which contains instances with force flag", func(t *testing.T) {
+		log.Info("should pass")
+		err := datasource.GetMetadataManager().UnregisterService(getContext(), &pb.DeleteServiceRequest{
+			ServiceId: serviceContainInstId,
+			Force:     true,
+		})
+		assert.NoError(t, err)
+	})
+
+	t.Run("delete a service which depended by consumer with force flag", func(t *testing.T) {
+		err := datasource.GetMetadataManager().UnregisterService(getContext(), &pb.DeleteServiceRequest{
+			ServiceId: serviceNoInstId,
+			Force:     true,
+		})
+		assert.NoError(t, err)
+	})
+}
+
+func TestService_Info(t *testing.T) {
+	var (
+		serviceID  string
+		instanceID string
+	)
+	ctx := getContext()
+	defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: serviceID, Force: true})
+
+	t.Run("register a tested service & instance, should be passed", func(t *testing.T) {
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
-				ServiceName: "delete_service_consumer_ms",
-				AppId:       "delete_service_ms",
+				ServiceName: "TestServic1",
+				AppId:       "default",
 				Version:     "1.0.0",
 				Level:       "FRONT",
 				Status:      "UP",
 			},
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respCreate.Response.GetCode())
-	})
+		serviceID = resp.ServiceId
 
-	t.Run("delete a service which contains instances with no force flag", func(t *testing.T) {
-		log.Info("should not pass")
-		resp, err := datasource.Instance().UnregisterService(getContext(), &pb.DeleteServiceRequest{
-			ServiceId: serviceContainInstId,
-			Force:     false,
+		instance := &pb.MicroServiceInstance{
+			ServiceId: serviceID,
+			Endpoints: []string{
+				"rest://[::]:301000/",
+			},
+			HostName: "delete-host-ms",
+			Status:   pb.MSI_UP,
+		}
+		respInstance, err := datasource.GetMetadataManager().RegisterInstance(ctx, &pb.RegisterInstanceRequest{
+			Instance: instance,
 		})
 		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, resp.Response.GetCode())
+		instanceID = respInstance.InstanceId
 	})
 
-	t.Run("delete a service which contains instances with force flag", func(t *testing.T) {
-		log.Info("should pass")
-		resp, err := datasource.Instance().UnregisterService(getContext(), &pb.DeleteServiceRequest{
-			ServiceId: serviceContainInstId,
+	t.Run("get tested service info, should be passed", func(t *testing.T) {
+		resp, err := datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
+			Options:     []string{"all"},
+			AppId:       "default",
+			ServiceName: "TestServic1",
+		})
+		assert.NoError(t, err)
+		assert.NotEqual(t, 0, len(resp.AllServicesDetail))
+		assert.NotEqual(t, 0, resp.Statistics.Services.Count)
+		assert.NotEqual(t, 0, resp.Statistics.Instances.Count)
+		assert.NotEqual(t, 0, resp.Statistics.Apps.Count)
+	})
+
+	t.Run("unregister tested service & instance, should be passed", func(t *testing.T) {
+		err := datasource.GetMetadataManager().UnregisterInstance(ctx, &pb.UnregisterInstanceRequest{
+			ServiceId:  serviceID,
+			InstanceId: instanceID,
+		})
+		assert.NoError(t, err)
+
+		err = datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{
+			ServiceId: serviceID,
 			Force:     true,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 	})
 
-	// todo: add delete service depended by consumer after finishing dependency management
-
-	t.Run("delete a service which depended by consumer with force flag", func(t *testing.T) {
-		log.Info("should pass")
-		resp, err := datasource.Instance().UnregisterService(getContext(), &pb.DeleteServiceRequest{
-			ServiceId: serviceNoInstId,
-			Force:     true,
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
-	})
-
-	t.Run("delete a service with no force flag", func(t *testing.T) {
-		log.Info("should not pass")
-		resp, err := datasource.Instance().UnregisterService(getContext(), &pb.DeleteServiceRequest{
-			ServiceId: serviceNoInstId,
-			Force:     false,
-		})
-		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, resp.Response.GetCode())
-	})
-}
-
-func TestService_Info(t *testing.T) {
 	t.Run("get all services", func(t *testing.T) {
 		log.Info("should be passed")
-		resp, err := datasource.Instance().GetServicesInfo(getContext(), &pb.GetServicesInfoRequest{
+		resp, err := datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
 			Options: []string{"all"},
 		})
 		assert.NoError(t, err)
 		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		resp, err = datasource.Instance().GetServicesInfo(getContext(), &pb.GetServicesInfoRequest{
+		resp, err = datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
 			Options: []string{""},
 		})
 		assert.NoError(t, err)
 		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		resp, err = datasource.Instance().GetServicesInfo(getContext(), &pb.GetServicesInfoRequest{
+		resp, err = datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
 			Options: []string{"tags", "rules", "instances", "schemas", "statistics"},
 		})
 		assert.NoError(t, err)
 		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		resp, err = datasource.Instance().GetServicesInfo(getContext(), &pb.GetServicesInfoRequest{
+		resp, err = datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
 			Options: []string{"statistics"},
 		})
 		assert.NoError(t, err)
 		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		resp, err = datasource.Instance().GetServicesInfo(getContext(), &pb.GetServicesInfoRequest{
+		resp, err = datasource.GetMetadataManager().ListServiceDetail(ctx, &pb.GetServicesInfoRequest{
 			Options:   []string{"instances"},
 			CountOnly: true,
 		})
@@ -684,10 +673,12 @@ func TestService_Detail(t *testing.T) {
 	var (
 		serviceId string
 	)
+	ctx := getContext()
+	defer datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{ServiceId: serviceId, Force: true})
 
 	t.Run("execute 'get detail' operation", func(t *testing.T) {
 		log.Info("should be passed")
-		resp, err := datasource.Instance().RegisterService(getContext(), &pb.CreateServiceRequest{
+		resp, err := datasource.GetMetadataManager().RegisterService(ctx, &pb.CreateServiceRequest{
 			Service: &pb.MicroService{
 				AppId:       "govern_service_group",
 				ServiceName: "govern_service_name",
@@ -697,18 +688,16 @@ func TestService_Detail(t *testing.T) {
 			},
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 		serviceId = resp.ServiceId
 
-		datasource.Instance().ModifySchema(getContext(), &pb.ModifySchemaRequest{
+		_, err = datasource.GetMetadataManager().ModifySchema(ctx, &pb.ModifySchemaRequest{
 			ServiceId: serviceId,
 			SchemaId:  "schemaId",
 			Schema:    "detail",
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		datasource.Instance().RegisterInstance(getContext(), &pb.RegisterInstanceRequest{
+		_, err = datasource.GetMetadataManager().RegisterInstance(ctx, &pb.RegisterInstanceRequest{
 			Instance: &pb.MicroServiceInstance{
 				ServiceId: serviceId,
 				Endpoints: []string{
@@ -719,49 +708,27 @@ func TestService_Detail(t *testing.T) {
 			},
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
 
-		log.Info("when get invalid service detail, should be failed")
-		respD, err := datasource.Instance().GetServiceDetail(getContext(), &pb.GetServiceRequest{
-			ServiceId: "",
-		})
-		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, respD.Response.GetCode())
-
-		log.Info("when get a service detail, should be passed")
-		respGetServiceDetail, err := datasource.Instance().GetServiceDetail(getContext(), &pb.GetServiceRequest{
-			ServiceId: serviceId,
-		})
-		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respGetServiceDetail.Response.GetCode())
-
-		respDelete, err := datasource.Instance().UnregisterService(getContext(), &pb.DeleteServiceRequest{
+		err = datasource.GetMetadataManager().UnregisterService(ctx, &pb.DeleteServiceRequest{
 			ServiceId: serviceId,
 			Force:     true,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, respDelete.Response.GetCode())
-
-		respGetServiceDetail, err = datasource.Instance().GetServiceDetail(getContext(), &pb.GetServiceRequest{
-			ServiceId: serviceId,
-		})
-		assert.NoError(t, err)
-		assert.NotEqual(t, pb.ResponseSuccess, respGetServiceDetail.Response.GetCode())
 	})
 }
 
 func TestApplication_Get(t *testing.T) {
 	t.Run("execute 'get apps' operation", func(t *testing.T) {
 		log.Info("when request is valid, should be passed")
-		resp, err := datasource.Instance().GetApplications(getContext(), &pb.GetAppsRequest{})
+		resp, err := datasource.GetMetadataManager().ListApp(getContext(), &pb.GetAppsRequest{})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.NotNil(t, resp)
 
-		resp, err = datasource.Instance().GetApplications(getContext(), &pb.GetAppsRequest{
+		resp, err = datasource.GetMetadataManager().ListApp(getContext(), &pb.GetAppsRequest{
 			Environment: pb.ENV_ACCEPT,
 		})
 		assert.NoError(t, err)
-		assert.Equal(t, pb.ResponseSuccess, resp.Response.GetCode())
+		assert.NotNil(t, resp)
 	})
 }
 
