@@ -17,42 +17,45 @@
 package integrationtest_test
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
-	"github.com/go-chassis/cari/discovery"
-	"github.com/gorilla/websocket"
-	"github.com/stretchr/testify/assert"
-	"net/http"
-	"strings"
-	"sync"
-
-	. "github.com/onsi/ginkgo"
-	. "github.com/onsi/gomega"
-	"github.com/widuu/gojson"
-
-	"bytes"
 	"io/ioutil"
 	"math/rand"
+	"net/http"
 	"strconv"
+	"strings"
+	"sync"
 	"testing"
 	"time"
 
+	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/gomega"
+
 	. "github.com/apache/servicecomb-service-center/integration"
+	"github.com/go-chassis/cari/discovery"
+	"github.com/gorilla/websocket"
+	"github.com/stretchr/testify/assert"
+	"github.com/widuu/gojson"
 )
 
 var _ = Describe("MicroService Api Test", func() {
 	var serviceName = ""
-	var serviceId = ""
+	var providerID = ""
+	var consumerID = ""
 	var serviceAppId = "integrationtestAppIdInstance"
 	var serviceVersion = "0.0.2"
 	var serviceInstanceID = ""
+	var alias = ""
 	Context("Tesing MicroService Instances API's", func() {
 		BeforeEach(func() {
 			schema := []string{"testSchema"}
 			properties := map[string]string{"attr1": "aa"}
 			serviceName = strconv.Itoa(rand.Intn(15))
+			alias = serviceAppId + ":" + serviceName
 			servicemap := map[string]interface{}{
 				"serviceName": serviceName,
+				"alias":       alias,
 				"appId":       serviceAppId,
 				"version":     serviceVersion,
 				"description": "examples",
@@ -75,8 +78,29 @@ var _ = Describe("MicroService Api Test", func() {
 			// Validate the service creation
 			Expect(resp.StatusCode).To(Equal(http.StatusOK))
 			respbody, _ := ioutil.ReadAll(resp.Body)
-			serviceId = gojson.Json(string(respbody)).Get("serviceId").Tostring()
-			Expect(len(serviceId)).Should(BeNumerically("==", LengthUUID))
+			providerID = gojson.Json(string(respbody)).Get("serviceId").Tostring()
+			Expect(len(providerID)).Should(BeNumerically("==", LengthUUID))
+
+			servicemap = map[string]interface{}{
+				"serviceName": "C_" + serviceName,
+				"appId":       serviceAppId,
+				"version":     serviceVersion,
+			}
+			bodyParams = map[string]interface{}{
+				"service": servicemap,
+			}
+			body, _ = json.Marshal(bodyParams)
+			bodyBuf = bytes.NewReader(body)
+			req, _ = http.NewRequest(POST, SCURL+REGISTERMICROSERVICE, bodyBuf)
+			req.Header.Set("X-Domain-Name", "default")
+			resp, err = scclient.Do(req)
+			Expect(err).To(BeNil())
+			defer resp.Body.Close()
+
+			// Validate the service creation
+			Expect(resp.StatusCode).To(Equal(http.StatusOK))
+			respbody, _ = ioutil.ReadAll(resp.Body)
+			consumerID = gojson.Json(string(respbody)).Get("serviceId").Tostring()
 
 			//Register MicroService Instance
 			endpoints := []string{"cse://127.0.0.1:9984"}
@@ -102,7 +126,7 @@ var _ = Describe("MicroService Api Test", func() {
 			bodyParams = map[string]interface{}{
 				"instance": instance,
 			}
-			url := strings.Replace(REGISTERINSTANCE, ":serviceId", serviceId, 1)
+			url := strings.Replace(REGISTERINSTANCE, ":serviceId", providerID, 1)
 			body, _ = json.Marshal(bodyParams)
 			bodyBuf = bytes.NewReader(body)
 			req, _ = http.NewRequest(POST, SCURL+url, bodyBuf)
@@ -115,13 +139,13 @@ var _ = Describe("MicroService Api Test", func() {
 			Expect(resp.StatusCode).To(Equal(http.StatusOK))
 			respbody, _ = ioutil.ReadAll(resp.Body)
 			serviceInstanceID = gojson.Json(string(respbody)).Get("instanceId").Tostring()
-			Expect(len(serviceId)).Should(BeNumerically("==", LengthUUID))
+			Expect(len(providerID)).Should(BeNumerically("==", LengthUUID))
 
 		})
 
 		AfterEach(func() {
 			if serviceInstanceID != "" {
-				url := strings.Replace(UNREGISTERINSTANCE, ":serviceId", serviceId, 1)
+				url := strings.Replace(UNREGISTERINSTANCE, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				req, _ := http.NewRequest(DELETE, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -129,8 +153,8 @@ var _ = Describe("MicroService Api Test", func() {
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 			}
 
-			if serviceId != "" {
-				url := strings.Replace(UNREGISTERMICROSERVICE, ":serviceId", serviceId, 1)
+			if providerID != "" {
+				url := strings.Replace(UNREGISTERMICROSERVICE, ":serviceId", providerID, 1)
 				req, _ := http.NewRequest(DELETE, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
 				resp, _ := scclient.Do(req)
@@ -150,7 +174,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyParams := map[string]interface{}{
 					"instancse": instance,
 				}
-				url := strings.Replace(REGISTERINSTANCE, ":serviceId", serviceId, 1)
+				url := strings.Replace(REGISTERINSTANCE, ":serviceId", providerID, 1)
 				body, _ := json.Marshal(bodyParams)
 				bodyBuf := bytes.NewReader(body)
 				req, _ := http.NewRequest(POST, SCURL+url, bodyBuf)
@@ -187,7 +211,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyParams := map[string]interface{}{
 					"instance": instance,
 				}
-				url := strings.Replace(REGISTERINSTANCE, ":serviceId", serviceId, 1)
+				url := strings.Replace(REGISTERINSTANCE, ":serviceId", providerID, 1)
 				body, _ := json.Marshal(bodyParams)
 				bodyBuf := bytes.NewReader(body)
 				req, _ := http.NewRequest(POST, SCURL+url, bodyBuf)
@@ -213,8 +237,8 @@ var _ = Describe("MicroService Api Test", func() {
 				}
 				healthcheck := map[string]interface{}{
 					"mode":     "push",
-					"interval": 30,
-					"times":    2,
+					"interval": 60,
+					"times":    3,
 				}
 				instance := map[string]interface{}{
 					"endpoints":   endpoints,
@@ -228,7 +252,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyParams := map[string]interface{}{
 					"instance": instance,
 				}
-				url := strings.Replace(REGISTERINSTANCE, ":serviceId", serviceId, 1)
+				url := strings.Replace(REGISTERINSTANCE, ":serviceId", providerID, 1)
 				body, _ := json.Marshal(bodyParams)
 				bodyBuf := bytes.NewReader(body)
 				req, _ := http.NewRequest(POST, SCURL+url, bodyBuf)
@@ -245,7 +269,7 @@ var _ = Describe("MicroService Api Test", func() {
 				//Verify the instanceID is different for two instance
 				Expect(serviceInst).NotTo(Equal(serviceInstanceID))
 				//Delete Instance
-				url = strings.Replace(UNREGISTERINSTANCE, ":serviceId", serviceId, 1)
+				url = strings.Replace(UNREGISTERINSTANCE, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInst, 1)
 				req, _ = http.NewRequest(DELETE, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -258,7 +282,7 @@ var _ = Describe("MicroService Api Test", func() {
 			It("Find Micro-service Info by AppID", func() {
 				req, _ := http.NewRequest(GET, SCURL+FINDINSTANCE+"?appId="+serviceAppId+"&serviceName="+serviceName+"&version="+serviceVersion, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -272,21 +296,53 @@ var _ = Describe("MicroService Api Test", func() {
 					}
 				}
 				Expect(foundMicroServiceInstance).To(Equal(true))
+
+				// wait dep handle
+				time.Sleep(3 * time.Second)
+
+				//Get Provider by ConsumerID
+				url := strings.Replace(GETCONPRODEPENDENCY, ":consumerId", consumerID, 1)
+				req, _ = http.NewRequest(GET, SCURL+url, nil)
+				req.Header.Set("X-Domain-Name", "default")
+				resp, _ = scclient.Do(req)
+				respbody, _ = ioutil.ReadAll(resp.Body)
+				Expect(resp.StatusCode).To(Equal(http.StatusOK))
+				respStruct := map[string][]map[string]interface{}{}
+				json.Unmarshal(respbody, &respStruct)
+				Expect(providerID).To(Equal(respStruct["providers"][0]["serviceId"]))
+
+				//Get Consumer by ProviderID
+				url = strings.Replace(GETPROCONDEPENDENCY, ":providerId", providerID, 1)
+				req, _ = http.NewRequest(GET, SCURL+url, nil)
+				req.Header.Set("X-Domain-Name", "default")
+				resp, _ = scclient.Do(req)
+				respbody, _ = ioutil.ReadAll(resp.Body)
+				Expect(resp.StatusCode).To(Equal(http.StatusOK))
+				respStruct = map[string][]map[string]interface{}{}
+				json.Unmarshal(respbody, &respStruct)
+				found := false
+				for _, c := range respStruct["consumers"] {
+					if c["serviceId"] == consumerID {
+						found = true
+						break
+					}
+				}
+				Expect(true).To(Equal(found))
 			})
 
 			It("Find Micro-service Info by invalid AppID", func() {
 				req, _ := http.NewRequest(GET, SCURL+FINDINSTANCE+"?appId=XXXX&serviceName="+serviceName+"&version="+serviceVersion, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				Expect(resp.StatusCode).To(Equal(http.StatusBadRequest))
 			})
 
 			It("Find Micro-Service Instance by ServiceID", func() {
-				url := strings.Replace(GETINSTANCE, ":serviceId", serviceId, 1)
-				req, _ := http.NewRequest(GET, SCURL+url, nil)
+				url := strings.Replace(GETINSTANCE, ":serviceId", providerID, 1)
+				req, _ := http.NewRequest(GET, SCURL+url+"?noCache=true", nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -306,17 +362,17 @@ var _ = Describe("MicroService Api Test", func() {
 				url := strings.Replace(GETINSTANCE, ":serviceId", "XX", 1)
 				req, _ := http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				Expect(resp.StatusCode).To(Equal(http.StatusBadRequest))
 			})
 
 			It("Find MicroServiceInstance with Service and IstanceID", func() {
-				url := strings.Replace(GETINSTANCEBYINSTANCEID, ":serviceId", serviceId, 1)
+				url := strings.Replace(GETINSTANCEBYINSTANCEID, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				req, _ := http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -327,19 +383,38 @@ var _ = Describe("MicroService Api Test", func() {
 			})
 
 			It("Find Micro-Service Instance by Invalid InstanceID", func() {
-				url := strings.Replace(GETINSTANCEBYINSTANCEID, ":serviceId", serviceId, 1)
+				url := strings.Replace(GETINSTANCEBYINSTANCEID, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", "XX", 1)
 				req, _ := http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				Expect(resp.StatusCode).To(Equal(http.StatusBadRequest))
 			})
 
+			It("Find Micro-service Info by alias", func() {
+				req, _ := http.NewRequest(GET, SCURL+FINDINSTANCE+"?noCache=true&appId="+serviceAppId+"&serviceName="+alias+"&version="+serviceVersion, nil)
+				req.Header.Set("X-Domain-Name", "default")
+				req.Header.Set("X-ConsumerId", consumerID)
+				resp, _ := scclient.Do(req)
+				respbody, _ := ioutil.ReadAll(resp.Body)
+				Expect(resp.StatusCode).To(Equal(http.StatusOK))
+				servicesStruct := map[string][]map[string]interface{}{}
+				json.Unmarshal(respbody, &servicesStruct)
+				foundMicroServiceInstance := false
+				for _, services := range servicesStruct["instances"] {
+					if services["instanceId"] == serviceInstanceID {
+						foundMicroServiceInstance = true
+						break
+					}
+				}
+				Expect(foundMicroServiceInstance).To(Equal(true))
+			})
+
 			It("Find Micro-Service Instance with rev", func() {
 				req, _ := http.NewRequest(GET, SCURL+FINDINSTANCE+"?appId="+serviceAppId+"&serviceName="+serviceName+"&version="+serviceVersion, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -348,7 +423,7 @@ var _ = Describe("MicroService Api Test", func() {
 
 				req, _ = http.NewRequest(GET, SCURL+FINDINSTANCE+"?appId="+serviceAppId+"&serviceName="+serviceName+"&version="+serviceVersion+"&rev="+rev, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ = scclient.Do(req)
 				ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusNotModified))
@@ -373,13 +448,13 @@ var _ = Describe("MicroService Api Test", func() {
 				}
 				notExistsInstance := map[string]interface{}{
 					"instance": map[string]interface{}{
-						"serviceId":  serviceId,
+						"serviceId":  providerID,
 						"instanceId": "notexisted",
 					},
 				}
 				providerInstance := map[string]interface{}{
 					"instance": map[string]interface{}{
-						"serviceId":  serviceId,
+						"serviceId":  providerID,
 						"instanceId": serviceInstanceID,
 					},
 				}
@@ -397,7 +472,7 @@ var _ = Describe("MicroService Api Test", func() {
 
 				req, _ := http.NewRequest(POST, SCURL+INSTANCEACTION, bytes.NewReader(body))
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ := scclient.Do(req)
 				ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusBadRequest))
@@ -405,7 +480,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyBuf := bytes.NewReader(body)
 				req, _ = http.NewRequest(POST, SCURL+INSTANCEACTION+"?type=query", bodyBuf)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ = scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -452,7 +527,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyParams := map[string]interface{}{
 					"properties": propertiesInstance,
 				}
-				url := strings.Replace(UPDATEINSTANCEMETADATA, ":serviceId", serviceId, 1)
+				url := strings.Replace(UPDATEINSTANCEMETADATA, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				body, _ := json.Marshal(bodyParams)
 				bodyBuf := bytes.NewReader(body)
@@ -466,10 +541,10 @@ var _ = Describe("MicroService Api Test", func() {
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
 				//Verify the updated properties
-				url = strings.Replace(GETINSTANCE, ":serviceId", serviceId, 1)
+				url = strings.Replace(GETINSTANCE, ":serviceId", providerID, 1)
 				req, _ = http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ = scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -491,7 +566,7 @@ var _ = Describe("MicroService Api Test", func() {
 				bodyParams := map[string]interface{}{
 					"properties": propertiesInstance,
 				}
-				url := strings.Replace(UPDATEINSTANCEMETADATA, ":serviceId", serviceId, 1)
+				url := strings.Replace(UPDATEINSTANCEMETADATA, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", "WRONGINSTANCEID", 1)
 				body, _ := json.Marshal(bodyParams)
 				bodyBuf := bytes.NewReader(body)
@@ -505,7 +580,7 @@ var _ = Describe("MicroService Api Test", func() {
 			})
 
 			It("Update Micro-Service Instance Status", func() {
-				url := strings.Replace(UPDATEINSTANCESTATUS, ":serviceId", serviceId, 1)
+				url := strings.Replace(UPDATEINSTANCESTATUS, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				req, _ := http.NewRequest(UPDATE, SCURL+url+"?value=DOWN", nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -517,10 +592,10 @@ var _ = Describe("MicroService Api Test", func() {
 				time.Sleep(time.Second)
 
 				//Verify the Instance Status
-				url = strings.Replace(GETINSTANCE, ":serviceId", serviceId, 1)
+				url = strings.Replace(GETINSTANCE, ":serviceId", providerID, 1)
 				req, _ = http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ = scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -537,7 +612,7 @@ var _ = Describe("MicroService Api Test", func() {
 			})
 
 			It("Update Micro-Service Instance Status with invalid Status", func() {
-				url := strings.Replace(UPDATEINSTANCESTATUS, ":serviceId", serviceId, 1)
+				url := strings.Replace(UPDATEINSTANCESTATUS, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				req, _ := http.NewRequest(UPDATE, SCURL+url+"?value=INVALID", nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -548,10 +623,10 @@ var _ = Describe("MicroService Api Test", func() {
 				Expect(resp.StatusCode).To(Equal(http.StatusBadRequest))
 
 				//Verify the Instance Status does not change the value
-				url = strings.Replace(GETINSTANCE, ":serviceId", serviceId, 1)
+				url = strings.Replace(GETINSTANCE, ":serviceId", providerID, 1)
 				req, _ = http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
-				req.Header.Set("X-ConsumerId", serviceId)
+				req.Header.Set("X-ConsumerId", consumerID)
 				resp, _ = scclient.Do(req)
 				respbody, _ := ioutil.ReadAll(resp.Body)
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
@@ -569,7 +644,7 @@ var _ = Describe("MicroService Api Test", func() {
 
 		By("Micro-Service Instance heartbeat API", func() {
 			It("Send HeartBeat for micro-service instance", func() {
-				url := strings.Replace(INSTANCEHEARTBEAT, ":serviceId", serviceId, 1)
+				url := strings.Replace(INSTANCEHEARTBEAT, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", serviceInstanceID, 1)
 				req, _ := http.NewRequest(UPDATE, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -581,7 +656,7 @@ var _ = Describe("MicroService Api Test", func() {
 			})
 
 			It("Send HeartBeat for wrong micro-service instance", func() {
-				url := strings.Replace(INSTANCEHEARTBEAT, ":serviceId", serviceId, 1)
+				url := strings.Replace(INSTANCEHEARTBEAT, ":serviceId", providerID, 1)
 				url = strings.Replace(url, ":instanceId", "XXX", 1)
 				req, _ := http.NewRequest(UPDATE, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
@@ -597,7 +672,7 @@ var _ = Describe("MicroService Api Test", func() {
 			It("Call the watcher API ", func() {
 				//This api gives 400 bad request for the integration test
 				// as integration test is not able to make ws connection
-				url := strings.Replace(INSTANCEWATCHER, ":serviceId", serviceId, 1)
+				url := strings.Replace(INSTANCEWATCHER, ":serviceId", providerID, 1)
 				req, _ := http.NewRequest(GET, SCURL+url, nil)
 				req.Header.Set("X-Domain-Name", "default")
 				resp, err := scclient.Do(req)
@@ -608,7 +683,6 @@ var _ = Describe("MicroService Api Test", func() {
 			})
 		})
 	})
-
 })
 
 func BenchmarkRegisterMicroServiceInstance(b *testing.B) {
