@@ -20,7 +20,7 @@ import (
 	"net/http"
 
 	"github.com/apache/servicecomb-service-center/pkg/rest"
-	"github.com/apache/servicecomb-service-center/server/rest/controller/v4"
+	v4 "github.com/apache/servicecomb-service-center/server/rest/controller/v4"
 )
 
 type DependencyService struct {
@@ -29,9 +29,7 @@ type DependencyService struct {
 
 func (this *DependencyService) URLPatterns() []rest.Route {
 	return []rest.Route{
-		{http.MethodPost, "/registry/v3/dependencies", this.AddDependenciesForMicroServices},
-		{http.MethodPut, "/registry/v3/dependencies", this.CreateDependenciesForMicroServices},
-		{http.MethodGet, "/registry/v3/microservices/:consumerId/providers", this.GetConProDependencies},
-		{http.MethodGet, "/registry/v3/microservices/:providerId/consumers", this.GetProConDependencies},
+		{http.MethodGet, "/registry/v3/microservices/:consumerId/providers", this.ListProviders},
+		{http.MethodGet, "/registry/v3/microservices/:providerId/consumers", this.ListConsumers},
 	}
 }
